@@ -95,7 +95,7 @@ against. Please run GNUmed as a non-root user.
 	sys.exit(1)
 
 #----------------------------------------------------------
-current_client_version = '1.8.2'
+current_client_version = '1.8.3'
 current_client_branch = '1.8'
 
 _log = None
@@ -132,7 +132,8 @@ _known_tools = [
 	'check_enc_epi_xref',
 	'export_pat_emr_structure',
 	'check_mimetypes_in_archive',
-	'read_all_rows_of_table'
+	'read_all_rows_of_table',
+	'fingerprint_db'
 ]
 
 
@@ -411,12 +412,15 @@ def log_startup_info():
 	for attr_name in os_attrs:
 		attr = getattr(os, attr_name)
 		if callable(attr):
-			_log.info('%s: %s', attr_name.rjust(40), attr())
+			try:
+				_log.info('%s: %s', attr_name.rjust(40), attr())
+			except Exception as exc:
+				_log.error('%s: a callable, but call failed (%s)', attr_name.rjust(40), exc)
 			continue
 		_log.info('%s: %s', attr_name.rjust(40), attr)
 	_log.info('process environment:')
 	for key, val in os.environ.items():
-		_log.info(' %s: %s' % (('${%s}' % key).rjust(40),	val))
+		_log.info(' %s: %s' % (('${%s}' % key).rjust(40), val))
 	import sysconfig
 	_log.info('module <sysconfig> info:')
 	_log.info(' platform [%s] -- python version [%s]', sysconfig.get_platform(), sysconfig.get_python_version())
@@ -799,6 +803,15 @@ def run_tool():
 		from Gnumed.business import gmEMRStructItems
 		return gmEMRStructItems.check_fk_encounter_fk_episode_x_ref()
 
+	if tool == 'fingerprint_db':
+		fname = 'db-fingerprint.txt'
+		result = gmPG2.get_db_fingerprint(fname = fname, with_dump = True)
+		if result == fname:
+			print('Success: %s' % fname)
+			return 0
+		print('Failed. Check the log for details.')
+		return -2
+
 	if tool == 'export_pat_emr_structure':
 		# setup praxis
 		from Gnumed.business import gmPraxis
@@ -854,7 +867,6 @@ def run_tool():
 			print('EMR text file:', fname)
 			# another patient ?
 			pat = gmPersonSearch.ask_for_patient()
-
 		return 0
 
 	# tool export_patient_as (vcf, gdt, ...)
